package com.unis.inspectionplan.client;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@FeignClient(name = "inspectionplan-server")
@Component
@Api(value = "检查计划", tags = "检查计划")
public interface InspectionplanFeign {

	@PostMapping(value = "/inspectionplan")
	@ApiOperation(value = "新增检查计划", notes = "参数：检查计划实体信息")
	public ResponseWrapper insert(@RequestBody InspectionplanVO jcjhvo);

	@ApiOperation(value = "根据仓号获取仓位信息", notes = "参数：仓号Id")
	@GetMapping(value = "/inspectionplan1/{cfbm}")
	public ResponseWrapper getStockInfoByCh(@PathVariable("cfbm") String cfbm);

	@PostMapping("/inspectionplanList/{pageNum}/{pageSize}")
	@ApiOperation(value = "根据条件分页获取信息列表")
	public ResponseWrapper getInspectionplanList(@RequestBody InspectionplanQueryVO queryvo,
			   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize);

	@GetMapping("/inspectionplan/{jhId}")
	@ApiOperation(value = "查看检查计划")
	public ResponseWrapper getInspectionplan(@PathVariable("jhId") String jhId);

	@PutMapping("/inspectionplan")
	@ApiOperation(value = "编辑检查计划")
	public ResponseWrapper updateInspectionplan(@RequestBody InspectionplanVO jcjhvo);

	@PutMapping("/inspectionplanonly")
	@ApiOperation(value = "更新检查计划")
    public ResponseWrapper updateInspectionplanonly(@RequestBody InspectionplanVO jcjhvo);

	@DeleteMapping("/inspectionplan/{jhId}")
	@ApiOperation(value = "撤回计划")
    public ResponseWrapper deleteInspectionlan(@PathVariable("jhId") String jhId);

	@PostMapping("/inspectionplan/deleteById")
	@ApiOperation(value = "删除计划")
	public ResponseWrapper deleteById(@RequestBody InspectionplanVO jcjhvo);

	@PostMapping("/inspectionplanplace/{pageNum}/{pageSize}")
    public ResponseWrapper inspectionplanplace(@RequestBody InspectionplanQueryVO queryvo,
    		   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize);

	/**
     * 查看检查计划
     * @param rwlxbh
     * @return
     */
    @GetMapping("/inspectionplanList/{rwlxbh}")
    public ResponseWrapper getInspectionplanList(@PathVariable("rwlxbh") String rwlxbh);

    /**
     * 根据条件分页获取信息列表
     */
    @ApiOperation(value = "根据计划id进行归档")
    @PutMapping("/inspectionplanplace/{jhId}")
    public ResponseWrapper inspectionplanPlace(@PathVariable(value = "jhId") String  jhId);

	/**
	 * @Title: inspectionplanTaskMain
	 * @Description:方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param inspectionplanQueryVo
	 * @param @return    设定文件
	 * @return ResponseWrapper    返回类型
	 * @throws
	*/
	@PostMapping("/inspectionplanMain")
	@ApiOperation(value = "获取取信息列表")
	public ResponseWrapper inspectionplanMain(@RequestBody InspectionplanQueryVO inspectionplanQueryVo);

	/**
	 *
	 * @Description: 分页查询某状态计划列表
	 * @author: 王帅
	 * @param: @param  pageSize
	 * @param: @param  pageNum
	 * @param: @return 参数
	 * @return: List<InspectionplanVO> 返回类型
	 */
	@ApiOperation(value = "分页查询某状态计划列表", notes = "分页查询某状态计划列表")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageSize", value = "页大小", dataType = "int", paramType = "query", required = true, defaultValue = "10"),
			@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query", required = true, defaultValue = "1"),
			@ApiImplicitParam(name = "status", value = "计划状态", dataType = "int", paramType = "query", required = true, defaultValue = "2") })
	@GetMapping("planList/status")
	public ResponseEntity<List<InspectionplanVO>> planUnfinishedList(
			@RequestParam(name = "pageSize", required = true, defaultValue = "10") int pageSize,
			@RequestParam(name = "pageNum", required = true, defaultValue = "1") int pageNum,
			@RequestParam(name = "status", required = true, defaultValue = "2") Integer status);

	/**
	 *
	 * @Description: 获取某状态下计划总数
	 * @author: 王帅
	 * @param: @param  status
	 * @param: @return 参数
	 * @return: Long 返回类型
	 */
	@ApiOperation(value = "获取某状态下计划总数", notes = "获取某状态下计划总数")
	@ApiImplicitParam(name = "status", value = "状态", dataType = "int", paramType = "query", required = true, defaultValue = "2")
	@GetMapping("planUnfinishedCount")
	public ResponseEntity<JSONObject> getPlanUnfinishedCount(
			@RequestParam(name = "status", required = true, defaultValue = "2") Integer status);


	@ApiOperation(value = "删除代办")
    @PutMapping("/backlog/{id}")
    public ResponseWrapper backlog(
			   @PathVariable(value = "id") String  id);
}
