package com.unis.inspectionplan.server.common.scheduled;

import com.unis.inspectionplan.common.constant.PlanConstant;
import com.unis.inspectionplan.common.vo.CheckformVO;
import com.unis.inspectionplan.common.vo.InspectionUnitVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.common.vo.YearPlanOrgVO;
import com.unis.inspectionplan.common.vo.YearPlanVO;
import com.unis.inspectionplan.server.dao.TJcjhDao;
import com.unis.inspectionplan.server.domain.BaseInfoDomain;
import com.unis.inspectionplan.server.domain.InspectionplanDomain;
import com.unis.inspectionplan.server.domain.YearPlanDomain;

import lombok.extern.slf4j.Slf4j;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * Created by admin on 2017/12/4.
 */
@Slf4j
@Component
public class PlanService {

	@Autowired
	TJcjhDao tJcjhDao;

	//@Scheduled(cron = "0 0 */1 * * ?")//每天每h
	// 这里不再使用，统一使用inspection-app InspectionPlanOverdueSchedule 超期计划检测
	public  void dowork(){
		String sign= new SimpleDateFormat("yyyy-MM-dd").format(new Date());
		int num=0;
		log.info("------超期计划-{}-开始检测",sign);
		try {
			num=execute(sign);
		} catch (IOException e) {
			e.printStackTrace();
		} catch (NoSuchAlgorithmException e) {
			e.printStackTrace();
		}
		log.info("---超期计划-{}-检测完毕,共<{}>条超期数据",sign,num);
	}

	public int  execute(String sign) throws IOException, NoSuchAlgorithmException {
		InspectionplanVO inspectionplanVO=new InspectionplanVO();
		//查询的字段
		inspectionplanVO.setJhzt(PlanConstant.OVERDUE.getValue());
		SimpleDateFormat sdf=new SimpleDateFormat("yyyy-MM-dd");
		Date date=null;
		try {
			date=sdf.parse(sdf.format(new Date()));
		} catch (ParseException e) {
			e.printStackTrace();
		}
		inspectionplanVO.setRwjsr(date);
		return tJcjhDao.updateOverDueByEntitySelective(inspectionplanVO);
	}
	
	@Autowired
	private YearPlanDomain yearPlanDomain;
	
	@Autowired
	private InspectionplanDomain inspectionplanDomain;
	
	@Scheduled(cron = "0 0 1 * * ?")//每天早上1点钟执行生成年度计划
	public  void annualPlan(){
		String sign= new SimpleDateFormat("yyyy-MM-dd").format(new Date());
		int num=0;
		log.info("------超期计划-{}-开始下发计划",sign);
		List<YearPlanVO> planVOs = yearPlanDomain.getndTodoList();
		for(YearPlanVO yearPlanVO:planVOs) {
			InspectionplanVO inspectionplanVO = new InspectionplanVO();
			List<InspectionUnitVO> inspectionUnitVOs = new ArrayList<InspectionUnitVO>();
			List<CheckformVO> checkformVOs = new ArrayList<CheckformVO>();
			inspectionplanVO.setJhName(yearPlanVO.getJhmc());
			inspectionplanVO.setRwqsr(yearPlanVO.getJhkssj());
			inspectionplanVO.setRwjsr(yearPlanVO.getJhjssj());
			inspectionplanVO.setCreateDate(new Date());
			inspectionplanVO.setXfr(yearPlanVO.getZdr());
			inspectionplanVO.setStatus(1);
			inspectionplanVO.setIsBjjcz(1);
			if(StringUtils.isNotEmpty(yearPlanVO.getOrgid())) {
				inspectionplanVO.setOrgId(yearPlanVO.getOrgid());
			} else {
				inspectionplanVO.setOrgId("LS001");
			}
			inspectionplanVO.setXfsj(new Date());
			inspectionplanVO.setRwlxId("5000110");
			inspectionplanVO.setRwlxmc("日常检查");
			inspectionplanVO.setJhzt(1);
			inspectionplanVO.setPlanid(yearPlanVO.getId());
			CheckformVO checkformVO = new CheckformVO();
			checkformVO.setBdId("BD20190822006");
			checkformVO.setBdName("现场检查记录表");
			checkformVO.setBdLu("/inspection/sceneCheckRecord");
			checkformVO.setStatus(1);
			checkformVOs.add(checkformVO);
			inspectionplanVO.setJcbd(checkformVOs);
			for(YearPlanOrgVO orgVO:yearPlanVO.getJcdwList()) {
				InspectionUnitVO inspectionUnitVO = new InspectionUnitVO();
				inspectionUnitVO.setJcdwId(orgVO.getJcdwid());
				inspectionUnitVO.setStatus(1);
				inspectionUnitVO.setJcdwName(orgVO.getJcdwmc());
				inspectionUnitVOs.add(inspectionUnitVO);
			}
			inspectionplanVO.setJcdwList(inspectionUnitVOs);
			num += inspectionplanDomain.insertJcjh(inspectionplanVO);
			yearPlanDomain.updateStatus(yearPlanVO.getId());
		}
//			num=execute(sign);
		log.info("---年度计划--检测完毕,共<{}>条年度数据",num);
	}
	
	@Autowired
	private BaseInfoDomain baseInfoDomain;
	
	@Scheduled(cron = "0 10 0 1 * ?")
	public void baseInfo() {
		baseInfoDomain.create();
	}

}
