package com.unis.inspectionplan.server.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionplan.common.vo.BaseInfoVO;
import com.unis.inspectionplan.common.vo.ReportVO;
import com.unis.inspectionplan.server.service.BaseInfoService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "基础信息", tags = "基础信息")
public class BaseInfoController {

	@Autowired
	private BaseInfoService baseInfoService;

	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "查询基础信息列表")
    @PostMapping("/baseinfo")
    public ResponseWrapper gather(@RequestBody List<String> orgids) {
    	try {
    		List<BaseInfoVO> insertJcjh = baseInfoService.gather(orgids);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "查询数据成功", insertJcjh);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }


	@ApiOperation(value = "更新详情")
    @PostMapping("/getbaseinfo/{orgid}")
    public ResponseWrapper gatherInfo(@PathVariable("orgid")String orgid) {
    	try {
    		BaseInfoVO baseInfoVO = baseInfoService.gatherInfo(orgid);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "查询数据成功", baseInfoVO);
		} catch (Exception e) {
			log.error(e.getMessage());
			log.error(e.getCause().toString());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }


	@ApiOperation(value = "查询详情")
    @PostMapping("/getbaseinfocha/{orgid}")
    public ResponseWrapper getbaseinfocha(@PathVariable("orgid")String orgid) {
    	try {
    		BaseInfoVO baseInfoVO = baseInfoService.getbaseinfocha(orgid);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "查询数据成功", baseInfoVO);
		} catch (Exception e) {
			log.error(e.getMessage());
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }



	@ApiOperation(value = "更新基础信息")
    @PutMapping("/getbaseinfo")
    public ResponseWrapper getbaseinfo(@RequestBody BaseInfoVO baseInfoVO) {
    	try {
    		baseInfoService.update(baseInfoVO);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "更新数据成功", baseInfoVO);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }



	@ApiOperation(value = "经费落实情况")
    @PutMapping("/jfReport/{nd}")
    public ResponseWrapper jflsqk(@RequestBody List<String> orgids,@PathVariable("nd")String nd) {
    	try {
    		List<ReportVO> reportVOs = baseInfoService.jflsqk(orgids,nd);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "获取数据成功", reportVOs);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }




	@ApiOperation(value = "执法队创建情况")
    @PutMapping("/zfdReport/{nd}")
    public ResponseWrapper zfdReport(@RequestBody List<String> orgids,@PathVariable("nd")String nd) {
    	try {
    		List<ReportVO> reportVOs = baseInfoService.zfdReport(orgids,nd);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "获取数据成功", reportVOs);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "服务异常", null);
		}
    }

}
