package com.unis.inspectionplan.server.controller;

import java.util.List;
import java.util.Map;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.server.service.InspectionplanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

@RestController
@Slf4j
@Api(value = "检查计划", tags = "检查计划")
public class InspectionplanController {

	@Autowired
	private InspectionplanService inspectionplanService;


	@ApiOperation(value = "根据仓号获取仓位信息", notes = "参数：仓号Id")
	@GetMapping(value = "/inspectionplan1/{cfbm}")
	public ResponseWrapper getStockInfoByCh(@PathVariable("cfbm") String cfbm){
		try {
			return ResponseWrapper.success(inspectionplanService.getStockInfoByCh(cfbm));
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error();
		}

	}
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "新增检查计划")
    @PostMapping("/inspectionplan")
    public ResponseWrapper insertInspectionplanService(@RequestBody InspectionplanVO jcjhvo) {
    	try {
    		int insertJcjh = inspectionplanService.insertJcjh(jcjhvo);
    		if(insertJcjh>0){
    			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", jcjhvo);
    		}
    		return ResponseWrapper.success(HttpStatus.OK.value(), "新增数据失败", insertJcjh);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "新增失败", null);
		}
    }


    /**
     * 根据条件分页获取信息列表
     */
    @PostMapping("/inspectionplanList/{pageNum}/{pageSize}")
    public ResponseWrapper getInspectionplanList(@RequestBody InspectionplanQueryVO queryvo,
    		   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize){
    	try {
    		long start=System.currentTimeMillis();
    		Map<String, Object> jcjhMap = inspectionplanService.getJcjhMap(queryvo, pageNum,pageSize);
			long end=System.currentTimeMillis();
			System.out.println("plan:"+(end-start));
    		return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功",jcjhMap);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}

    }

    /**
     * 查看检查计划
     * @param jhId
     * @return
     */
    @GetMapping("/inspectionplan/{jhId}")
    public ResponseWrapper getInspectionplan(@PathVariable("jhId") String jhId){

    	try {
    		InspectionplanVO inspectionplanVO = inspectionplanService.getJcjh(jhId);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "成功",inspectionplanVO);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询信息失败", null);
		}
    }

    /**
     * 编辑检查计划
     * @param jcjhvo
     * @return
     */
    @PutMapping("/inspectionplan")
    public ResponseWrapper updateInspectionplan(@RequestBody InspectionplanVO jcjhvo){

    	try {
    		int updateJcjh = inspectionplanService.updateJcjh(jcjhvo);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "编辑成功",jcjhvo);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "编辑失败", null);
		}
    }

    /**
     * 更新计划
     * @param jcjhvo
     * @return
     */
    @PutMapping("/inspectionplanonly")
    public ResponseWrapper updateInspectionplanonly(@RequestBody InspectionplanVO jcjhvo){
    	try {
    		int updateJcjh = inspectionplanService.updateInspectionlanonly(jcjhvo);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "下发成功",updateJcjh);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败", null);
		}
    }


    /**
     * 撤回计划
     * @param jhId
     * @return
     */
    @DeleteMapping("/inspectionplan/{jhId}")
    public ResponseWrapper deleteInspectionlan(@PathVariable("jhId") String jhId){

    		try {
    			int deleteInspectionlan = inspectionplanService.deleteInspectionlan(jhId);
    			return ResponseWrapper.success(HttpStatus.OK.value(), "撤回成功",deleteInspectionlan);
    		} catch (Exception e) {
    			log.error(e.getMessage());
    			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "撤回失败", null);
    		}
    }

	@PostMapping("/inspectionplan/deleteById")
	@ApiOperation(value = "删除计划")
	public ResponseWrapper deleteById(@RequestBody InspectionplanVO jcjhvo){
		return inspectionplanService.deleteById(jcjhvo);
	}


    /**
     * 查看检查计划
     * @param rwlxbh
     * @return
     */
    @ApiOperation(value = "任务类型获取未过期及归档任务")
    @GetMapping("/inspectionplanList/{rwlxbh}")
    public ResponseWrapper getInspectionplanList(@PathVariable("rwlxbh") String rwlxbh){

    	try {
    		List<InspectionplanVO> inspectionplanVOs = inspectionplanService.getInspectionplanList(rwlxbh);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "成功",inspectionplanVOs);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询信息失败", null);
		}
    }

    /**
     * 根据条件分页获取信息列表
     */
    @ApiOperation(value = "分页获取归档信息")
    @PostMapping("/inspectionplanplace/{pageNum}/{pageSize}")
    public ResponseWrapper inspectionplanplace(@RequestBody InspectionplanQueryVO queryvo,
    		   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize){
    	try {

    		Map<String, Object> jcjhMap = inspectionplanService.getplaceList(queryvo, pageNum,pageSize);

    		return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功",jcjhMap);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}

    }


    /**
     * 根据条件分页获取信息列表
     */
    @ApiOperation(value = "根据计划id进行归档")
    @PutMapping("/inspectionplanplace/{jhId}")
    public ResponseWrapper inspectionplanPlace(
			   @PathVariable(value = "jhId") String  jhId){
    	try {

    		int vo  = inspectionplanService.inspectionplanplace(jhId);

    		return ResponseWrapper.success(HttpStatus.OK.value(), "任务归档成功",vo);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "任务归档失败", null);
		}

    }

    /**
     *
     * @Title: inspectionplanMain
     * @Description:方法描述:(这里用一句话描述这个方法的作用)
     * @param @param inspectionplanQueryVo
     * @param @return    设定文件
     * @return ResponseWrapper    返回类型
     * @throws
     */
	@PostMapping("/inspectionplanMain")
	@ApiOperation(value = "获取取信息列表")
	public ResponseWrapper inspectionplanMain(@RequestBody InspectionplanQueryVO inspectionplanQueryVo) {
		 try {
				List<InspectionplanVO> inspectionplanVOs= inspectionplanService.inspectionplanMain(inspectionplanQueryVo);
				if (inspectionplanVOs==null) {
					return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "查询数据为空", null);
				}
				return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", inspectionplanVOs);
		} catch (Exception e) {
		     e.printStackTrace();
			log.error(e.getMessage());
		}
	       return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 *
	 * @Description: 分页查询某状态计划列表
	 * @author: 王帅
	 * @param: @param  pageSize
	 * @param: @param  pageNum
	 * @param: @return 参数
	 * @return: List<InspectionplanVO> 返回类型
	 */
	@ApiOperation(value = "分页查询某状态计划列表", notes = "分页查询某状态计划列表")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageSize", value = "页大小", dataType = "int", paramType = "query", required = true, defaultValue = "10"),
			@ApiImplicitParam(name = "pageNum", value = "当前页", dataType = "int", paramType = "query", required = true, defaultValue = "1"),
			@ApiImplicitParam(name = "status", value = "计划状态", dataType = "int", paramType = "query", required = true, defaultValue = "2") })
	@GetMapping("planList/status")
	public ResponseEntity<List<InspectionplanVO>> planUnfinishedList(
			@RequestParam(name = "pageSize", required = true, defaultValue = "10") int pageSize,
			@RequestParam(name = "pageNum", required = true, defaultValue = "1") int pageNum,
			@RequestParam(name = "status", required = true, defaultValue = "2") Integer status) {
		List<InspectionplanVO> page = inspectionplanService.planUnfinishedList(pageSize, pageNum, status);

		return CollectionUtils.isNotEmpty(page) ? ResponseEntity.status(HttpStatus.OK).body(page) : ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
	}

	/**
	 *
	 * @Description: 获取某状态下计划总数
	 * @author: 王帅
	 * @param: @param  status
	 * @param: @return 参数
	 * @return: Long 返回类型
	 */
	@ApiOperation(value = "获取某状态下计划总数", notes = "获取某状态下计划总数")
	@ApiImplicitParam(name = "status", value = "状态", dataType = "int", paramType = "query", required = true, defaultValue = "2")
	@GetMapping("planUnfinishedCount")
	public ResponseEntity<JSONObject> getPlanUnfinishedCount(
			@RequestParam(name = "status", required = true, defaultValue = "2") Integer status) {
		JSONObject obj = new JSONObject();
		Long count = 0L;
		try {
			count = inspectionplanService.getPlanUnfinishedCount(status);
			obj.put("count", count);
		} catch (Exception e) {
			return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(null);
		}

		return ResponseEntity.status(HttpStatus.OK).body(obj);
	}





	/**
     * 根据条件分页获取信息列表
     */
    @ApiOperation(value = "删除代办")
    @PutMapping("/backlog/{id}")
    public ResponseWrapper backlog(
			   @PathVariable(value = "id") String  id){
    	try {

    		int vo  = inspectionplanService.backlog(id);

    		return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功",vo);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "删除失败", null);
		}

    }
}
