package com.unis.inspectionplan.server.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectionplan.common.vo.CheckformVO;
import com.unis.inspectionplan.common.vo.InspectionUnitVO;
import com.unis.inspectionplan.common.vo.InspectionplanQueryVO;
import com.unis.inspectionplan.common.vo.InspectionplanVO;
import com.unis.inspectionplan.common.vo.YearPlanChartVO;
import com.unis.inspectionplan.common.vo.YearPlanOrgVO;
import com.unis.inspectionplan.common.vo.YearPlanVO;
import com.unis.inspectionplan.server.domain.InspectionplanDomain;
import com.unis.inspectionplan.server.domain.YearPlanDomain;
import com.unis.inspectionplan.server.service.InspectionplanService;
import com.unis.inspectionplan.server.service.YearPlanService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
 
@RestController
@Slf4j
@Api(value = "年度计划", tags = "年度计划")
public class YearPlanController {
	
	@Autowired
	private YearPlanService yearPlanService;
 
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "新增年度计划")
    @PostMapping("/yearplan")
    public ResponseWrapper insertyearplan(@RequestBody YearPlanVO yearPlanVO) {
    	try {
    		int insertJcjh = yearPlanService.yearplan(yearPlanVO);
    		if(insertJcjh>0){
    			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", yearPlanVO);
    		}
    		return ResponseWrapper.success(HttpStatus.OK.value(), "新增数据失败", insertJcjh);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "新增失败", null);
		}
    }
	
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "修改检查计划")
    @PutMapping("/yearplan")
    public ResponseWrapper updateyearplan(@RequestBody YearPlanVO yearPlanVO) {
    	try {
    		String insertJcjh = yearPlanService.updateyearplan(yearPlanVO);
//    		if(insertJcjh>0){
//    			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", yearPlanVO);
//    		}
    		return ResponseWrapper.success(HttpStatus.OK.value(), insertJcjh, yearPlanVO);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "更新失败", null);
		}
    }
	
	
	/**
	 * 新增检查计划
	 * @return
	 */
	@ApiOperation(value = "删除检查计划")
	@DeleteMapping("/yearplan/{id}")
    public ResponseWrapper yearplan(@PathVariable(value="id")String id) {
    	try {
    		String insertJcjh = yearPlanService.yearplan(id);
//    		if(insertJcjh>0){
//    			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", yearPlanVO);
//    		}
    		return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "更新失败", null);
		}
    }
	
	
	/**
     * 根据条件分页获取信息列表
     */
    @PostMapping("/yearplan/{pageNum}/{pageSize}")
    public ResponseWrapper getInspectionplanPage(@RequestParam(value="jhnf",required = false) String jhnf,
												 @RequestParam(value="jhmc",required = false) String jhmc,
    		   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize){
    	try {
    		long start=System.currentTimeMillis();
    		Map<String, Object> jcjhMap = yearPlanService.getJcjhMap(jhnf,jhmc, pageNum,pageSize);
			long end=System.currentTimeMillis();
			System.out.println("plan:"+(end-start));
    		return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功",jcjhMap);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}
    	
    }
    
    /**
     * 根据条件分页获取信息列表
     */
    @PostMapping("/yearplanChat")
    public ResponseWrapper getInspectionplanList(@RequestParam(value="jhnf",required = false) String jhnf, @RequestParam(value="jhmc",required = false) String jhmc){
    	try {
    		List<YearPlanChartVO> yearPlanChartVOs = yearPlanService.getInspectionplanList(jhnf, jhmc);
    		return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功",yearPlanChartVOs);
		} catch (Exception e) {
			log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}
    	
    }
    
    @Autowired
	private YearPlanDomain yearPlanDomain;
	
	@Autowired
	private InspectionplanDomain inspectionplanDomain;
    
    @PostMapping("/test")
    public ResponseWrapper test(){
    	int num=0;
    	List<YearPlanVO> planVOs = yearPlanDomain.getndTodoList();
		for(YearPlanVO yearPlanVO:planVOs) {
			InspectionplanVO inspectionplanVO = new InspectionplanVO();
			List<InspectionUnitVO> inspectionUnitVOs = new ArrayList<InspectionUnitVO>();
			List<CheckformVO> checkformVOs = new ArrayList<CheckformVO>();
			inspectionplanVO.setJhName(yearPlanVO.getJhmc());
			inspectionplanVO.setRwqsr(yearPlanVO.getJhkssj());
			inspectionplanVO.setRwjsr(yearPlanVO.getJhjssj());
			inspectionplanVO.setCreateDate(new Date());
			inspectionplanVO.setXfr(yearPlanVO.getZdr());
			inspectionplanVO.setStatus(1);
			inspectionplanVO.setIsBjjcz(1);
			inspectionplanVO.setOrgId("LS001");
			inspectionplanVO.setXfsj(new Date());
			inspectionplanVO.setRwlxId("5000110");
			inspectionplanVO.setRwlxmc("日常检查");
			inspectionplanVO.setJhzt(1);
			CheckformVO checkformVO = new CheckformVO();
			checkformVO.setBdId("BD20190822006");
			checkformVO.setBdName("现场检查记录表");
			checkformVO.setBdLu("/inspection/sceneCheckRecord");
			checkformVO.setStatus(1);
			checkformVOs.add(checkformVO);
			inspectionplanVO.setJcbd(checkformVOs);
			for(YearPlanOrgVO orgVO:yearPlanVO.getJcdwList()) {
				InspectionUnitVO inspectionUnitVO = new InspectionUnitVO();
				inspectionUnitVO.setJcdwId(orgVO.getJcdwid());
				inspectionUnitVO.setStatus(1);
				inspectionUnitVO.setJcdwName(orgVO.getJcdwmc());
				inspectionUnitVOs.add(inspectionUnitVO);
			}
			inspectionplanVO.setJcdwList(inspectionUnitVOs);
			num += inspectionplanDomain.insertJcjh(inspectionplanVO);
		}
		return ResponseWrapper.success(num);
    }
}